==> humhub-1.8.0-beta.1.tar.gz: humhub-1.8.0-beta.1/protected/humhub/modules/content/messages/hr/base.php <==
<?php
return array (
  '(Also visible to non-members of this space)' => '(Vidljivo i nečlanovima ovog prostora)',
  '<strong>Confirm</strong> post deletion' => '<strong>Potvrdi</strong> brisanje objave',
  '<strong>Move</strong> content' => '<strong>Premjesti</strong> sadržaj',
  '<strong>Permalink</strong> to this post' => '<strong>Permalink</strong> na ovu objavu',
  'Add a member to notify' => 'Dodaj člana za obaviještavanje',
  'Archived' => 'Arhivirano',
  'Attach Files' => 'Priložite datoteke',
  'Back to stream' => 'Povratak na stream',
  'Cancel' => 'Poništi',
  'Cancel Edit' => 'Poništi uređivanje',
  'Content' => 'Sadržaj',
  'Content Tag with invalid contentcontainer_id assigned.' => 'Dodijeljena je oznaka za sadržaj s nevažećim contentcontainer_id.',
  'Content has been moved to {spacename}' => 'Sadržaj je premješten u prostor {spacename}',
  'Content visibility' => 'Vidljivost sadržaja',
  'Could not delete content!' => 'Nije bilo moguće izbrisati sadržaj!',
  'Could not delete content: Access denied!' => 'Nije bilo moguće izbrisati sadržaj: Pristup je odbijen!',
  'Could not find requested content!' => 'Nije bilo moguće pronaći traženi sadržaj!',
  'Created by me' => 'Kreirao sam',
  'Creation time' => 'Vrijeme kreiranja',
  'Delete' => 'Obriši',
  'Do you really want to delete this post? All likes and comments will be lost!' => 'Želite li doista izbrisati taj post? Svi \'\'like-ovi\'\' i komentari bit će izgubljeni!',
  'Edit' => 'Uredi',
  'Filter' => 'Filter',
  'Invalid content id given!' => 'Navedeni ID sadržaj nije valjan!',
  'Invalid request method!' => 'Nevažeći način zahtjeva!',
  'Invalid space selection.' => 'Nevažeći odabir prostora.',
  'Last update' => 'Zadnje ažuriranje',
  'Last updated {time}' => 'Posljednje ažuriranje {time}',
  'Load more' => 'Učitaj još',
  'Change to "Private"' => 'Učini privatnim',
  'Change to "Public"' => 'Učini javnim',
  'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'Dosegnut je maksimalan broj prikvačenih stavki!<br>Odjednom možete prikvačiti najviše {count} stavki.',
  'Move content' => 'Premjesti sadržaj',
  'Move to archive' => 'Premjesti u arhivu',
  'No matches with your selected filters!' => 'Nema podudaranja s vašim postavljenim filterima!',
  'None' => 'Nijedan',
  'Nothing here yet!' => 'Još ništa ovdje!',
  'Notify members' => 'Obavijesti članove',
  'Only private content' => 'Samo privatni sadržaj',
  'Only public content' => 'Samo javni sadržaj',
  'Permalink' => 'Permalink',
  'Pin to top' => 'Prikači na vrh',
  'Pinned' => 'Prikačeno',
  'Public' => 'Javno',
  'Specify who can see this content.' => 'Navedite ko može vidjeti ovaj sadržaj.',
  'Submit' => 'Potvrdi',
  'Tag' => 'Tag',
  'Target Space' => 'Ciljani prostor',
  'The author of this content is not allowed to create private content within the selected space.' => 'Autoru ovog sadržaja nije dopušteno stvarati privatni sadržaj u odabranom prostoru.',
  'The author of this content is not allowed to create public content within the selected space.' => 'Autoru ovog sadržaja nije dopušteno stvarati javni sadržaj u odabranom prostoru.',
  'The author of this content is not allowed to create this type of content within this space.' => 'Autor ovog sadržaja ne smije stvarati ovu vrstu sadržaja u ovom prostoru.',
  'The content can\'t be moved to its current space.' => 'Sadržaj se ne može premjestiti u trenutni prostor.',
  'The content has been archived.' => 'Sadržaj je arhiviran.',
  'The content has been deleted.' => 'Sadržaj je obrisan.',
  'The content has been unarchived.' => 'Sadržaj je dearhiviran.',
  'The given name is already in use.' => 'Navedeno ime već je u upotrebi.',
  'The module {moduleName} is not enabled on the selected target space.' => 'Modul {moduleName} nije omogućen na odabranom prostoru.',
  'This action is disabled!' => 'Ova je radnja onemogućena!',
  'This content type can\'t be moved due to a missing module-id setting.' => 'Ovu vrstu sadržaja nije moguće premjestiti zbog nedostajuće postavke id-a modula.',
  'This content type can\'t be moved.' => 'Ovu vrstu sadržaja nije moguće premjestiti.',
  'This space is archived.' => 'Prostor je arhiviran.',
  'This space is not visible!' => 'Ovaj prostor nije vidljiv!',
  'Topics' => 'Teme',
  'Turn off notifications' => 'Isključi obavijesti',
  'Turn on notifications' => 'Uključi obavijesti',
  'Unarchive' => 'Dearhiviraj',
  'Unpin' => 'Otkači',
  'Updated' => 'Ažurirano',
  'Visible also to unregistered users' => 'Vidljivo i neregistriranim korisnicima',
  'Visible only to you' => 'Vidljivo samo vama',
  'Visible to all Space members' => 'Vidljivo svim članovima svemira',
  'Visible to all signed in users' => 'Vidljivo svim prijavljenim korisnicima',
  'Visible to friends of {displayName}' => 'Vidljivo prijateljima {displayName}',
  'Visible to you and {displayName}' => 'Vidljivo vama i {displayName}',
  'Visible to your friends' => 'Vidljivo vašim prijateljima',
  'Where I\'m involved' => 'Tamo gdje sam uključen',
  'With file attachments' => 'S prilozima datoteka',
  'You do not have the permission to move this content to the given space.' => 'Nemate dozvolu za premještanje ovog sadržaja u zadani prostor.',
  'You do not have the permission to move this content.' => 'Nemate dozvolu za premještanje ovog sadržaja.',
  'Your last edit state has been saved!' => 'Vaše zadnje uređeno stanje je spremljeno!',
  'in' => 'u',
);

==> humhub-1.17.0-beta.1.tar.gz: humhub-1.17.0-beta.1/protected/humhub/modules/content/messages/hr/base.php <==
<?php
return array (
  '(Also visible to non-members of this space)' => '(Vidljivo i nečlanovima ovog prostora)',
  '(Also visible to people who are not logged in)' => '(Također vidljivo osobama koje nisu prijavljene)',
  '<strong>Delete</strong> content?' => '',
  '<strong>Move</strong> content' => '<strong>Premjesti</strong> sadržaj',
  '<strong>Permalink</strong> to this post' => '<strong>Permalink</strong> na ovu objavu',
  '<strong>Scheduling</strong> Options' => '',
  'Activate scheduling' => '',
  'Add a member to notify' => 'Dodaj člana za obaviještavanje',
  'Add tag...' => '',
  'Advanced Content Search' => '',
  'Archived' => 'Arhivirano',
  'Attach Files' => 'Priložite datoteke',
  'Back to stream' => 'Povratak na stream',
  'Cancel' => 'Poništi',
  'Cancel Edit' => 'Poništi uređivanje',
  'Cannot notify the author.' => '',
  'Change to "Private"' => 'Učini privatnim',
  'Change to "Public"' => 'Učini javnim',
  'Comments are locked' => '',
  'Comments are unlocked' => '',
  'Configure' => 'Konfiguriraj',
  'Confirm' => 'Potvrdi',
  'Content' => 'Sadržaj',
  'Content Tag with invalid contentcontainer_id assigned.' => 'Dodijeljena je oznaka za sadržaj s nevažećim contentcontainer_id.',
  'Content has been moved to {spacename}' => 'Sadržaj je premješten u prostor {spacename}',
  'Could not find requested content!' => 'Nije bilo moguće pronaći traženi sadržaj!',
  'Create as draft' => '',
  'Created at:' => '',
  'Created by me' => 'Kreirao sam',
  'Creation time' => 'Vrijeme kreiranja',
  'Delete' => 'Obriši',
  'Deleted' => 'Obrisano',
  'Do you want to delete this content, including all comments and attachments?<br><br>Please note: If a stream entry was created using a module, the original content that this entry is linked to will also be deleted.' => '',
  'Draft' => '',
  'Edit' => 'Uredi',
  'Enable' => 'Omogući',
  'Enabled' => 'Aktivirano',
  'Filter' => 'Filter',
  'Hidden' => '',
  'I\'m involved' => 'Tamo gdje sam uključen',
  'Invalid content id given!' => 'Navedeni ID sadržaj nije valjan!',
  'Invalid request method!' => 'Nevažeći način zahtjeva!',
  'Invalid space selection.' => 'Nevažeći odabir prostora.',
  'Last update' => 'Zadnje ažuriranje',
  'Last updated {time}' => 'Posljednje ažuriranje {time}',
  'Load more' => 'Učitaj još',
  'Lock comments' => '',
  'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'Dosegnut je maksimalan broj prikvačenih stavki!<br>Odjednom možete prikvačiti najviše {count} stavki.',
  'Move content' => 'Premjesti sadržaj',
  'Move to archive' => 'Premjesti u arhivu',
  'New Updates Available!' => '',
  'No matches with your selected filters!' => 'Nema podudaranja s vašim postavljenim filterima!',
  'No tags found for the given query' => '',
  'None' => 'Nijedan',
  'Note: Due to technical reasons there may be a delay of a few minutes.' => '',
  'Nothing here yet!' => 'Još ništa ovdje!',
  'Notify members' => 'Obavijesti članove',
  'Permalink' => 'Permalink',
  'Pin to top' => 'Prikači na vrh',
  'Pinned' => 'Prikačeno',
  'Private' => 'Privatno',
  'Public' => 'Javno',
  'Publish draft' => '',
  'Save as draft' => '',
  'Save scheduling' => '',
  'Schedule publication' => '',
  'Scheduled for {dateTime}' => '',
  'Select type...' => '',
  'Specify who can see this content.' => 'Navedite ko može vidjeti ovaj sadržaj.',
  'Submit' => 'Potvrdi',
  'Tag' => 'Tag',
  'Target Space' => 'Ciljani prostor',
  'The author of this content is not allowed to create private content within the selected space.' => 'Autoru ovog sadržaja nije dopušteno stvarati privatni sadržaj u odabranom prostoru.',
  'The author of this content is not allowed to create public content within the selected space.' => 'Autoru ovog sadržaja nije dopušteno stvarati javni sadržaj u odabranom prostoru.',
  'The author of this content is not allowed to create this type of content within this space.' => 'Autor ovog sadržaja ne smije stvarati ovu vrstu sadržaja u ovom prostoru.',
  'The content can\'t be moved to its current space.' => 'Sadržaj se ne može premjestiti u trenutni prostor.',
  'The content cannot be published!' => '',
  'The content has been archived.' => 'Sadržaj je arhiviran.',
  'The content has been deleted.' => 'Sadržaj je obrisan.',
  'The content has been successfully published.' => '',
  'The content has been unarchived.' => 'Sadržaj je dearhiviran.',
  'The given name is already in use.' => 'Navedeno ime već je u upotrebi.',
  'The module {moduleName} is not enabled on the selected target space.' => 'Modul {moduleName} nije omogućen na odabranom prostoru.',
  'This action is disabled!' => 'Ova je radnja onemogućena!',
  'This content type can\'t be moved due to a missing module-id setting.' => 'Ovu vrstu sadržaja nije moguće premjestiti zbog nedostajuće postavke id-a modula.',
  'This content type can\'t be moved.' => 'Ovu vrstu sadržaja nije moguće premjestiti.',
  'This space is archived.' => 'Prostor je arhiviran.',
  'This space is not visible!' => 'Ovaj prostor nije vidljiv!',
  'Topics' => 'Teme',
  'Turn off notifications' => 'Isključi obavijesti',
  'Turn on notifications' => 'Uključi obavijesti',
  'Unarchive' => 'Dearhiviraj',
  'Unlock comments' => 'Otključaj komentare',
  'Unpin' => 'Otkači',
  'Updated' => 'Ažurirano',
  'Visible also to unregistered users' => 'Vidljivo i neregistriranim korisnicima',
  'Visible only to you' => 'Vidljivo samo vama',
  'Visible to all Space members' => 'Vidljivo svim članovima svemira',
  'Visible to all signed in users' => 'Vidljivo svim prijavljenim korisnicima',
  'Visible to friends of {displayName}' => 'Vidljivo prijateljima {displayName}',
  'Visible to you and {displayName}' => 'Vidljivo vama i {displayName}',
  'Visible to your friends' => 'Vidljivo vašim prijateljima',
  'With attachments' => 'S prilozima datoteka',
  'You cannot block the space owner!' => '',
  'You cannot block the user of the same container!' => '',
  'You cannot block yourself!' => '',
  'You do not have the permission to move this content to the given space.' => 'Nemate dozvolu za premještanje ovog sadržaja u zadani prostor.',
  'You do not have the permission to move this content.' => 'Nemate dozvolu za premještanje ovog sadržaja.',
  'Your last edit state has been saved!' => 'Vaše zadnje uređeno stanje je spremljeno!',
  'in' => 'u',
);
